@@ -3,7 +3,7 @@ from dotenv import load_dotenv
 
 from kclii.database.database import Base, engine
 from kclii.modules.profiles import profiles
-from scripts.scripts import install_scripts
+from kclii.scripts.scripts import install_scripts
 
 import kclii.modules.profiles.models
 
@@ -25,7 +25,7 @@ def hello(name: str = ""):
 
 @app.command()
 def version() -> None:
-    print("0.1.3")
+    print("0.1.4")
 
 
 if __name__ == "__main__":
